@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,6 +23,13 @@
 #include "PimCommon/ConfigureImmutableWidgetUtils"
 #include "sieveeditorglobalconfig.h"
 
+#ifdef WITH_KUSERFEEDBACK
+#include "userfeedback/userfeedbackmanager.h"
+#include <KUserFeedback/Provider>
+#include <KUserFeedback/FeedbackConfigWidget>
+#endif
+
+
 #include <KLocalizedString>
 #include <KSharedConfig>
 
@@ -33,44 +40,60 @@
 #include <QPushButton>
 
 SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
-    : QDialog(parent)
+    : KPageDialog(parent)
 {
-    setWindowTitle(i18n("Configure"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
-    okButton->setDefault(true);
-    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    connect(buttonBox, &QDialogButtonBox::accepted, this, &SieveEditorConfigureDialog::accept);
-    connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveEditorConfigureDialog::reject);
+    setWindowTitle(i18nc("@title:window", "Configure"));
+    setFaceType(KPageDialog::List);
 
-    mTabWidget = new QTabWidget(this);
-    mTabWidget->setObjectName(QStringLiteral("tabwidget"));
+    buttonBox()->setStandardButtons(QDialogButtonBox::Ok| QDialogButtonBox::Cancel);
+
+    connect(buttonBox(), &QDialogButtonBox::accepted, this, &SieveEditorConfigureDialog::accept);
+    connect(buttonBox(), &QDialogButtonBox::rejected, this, &SieveEditorConfigureDialog::reject);
 
     //Server page
-    QWidget *w = new QWidget;
-    mTabWidget->addTab(w, i18n("Sieve Server"));
-
-    QVBoxLayout *layout = new QVBoxLayout;
-    w->setLayout(layout);
+    QWidget *serverConfigureWiget = new QWidget;
+    QVBoxLayout *layout = new QVBoxLayout(serverConfigureWiget);
     mServerWidget = new SieveEditorConfigureServerWidget;
     layout->addWidget(mServerWidget);
 
     mCloseWallet = new QCheckBox(i18n("Close wallet when close application"));
     layout->addWidget(mCloseWallet);
 
+    KPageWidgetItem *serverPageWidgetPage = new KPageWidgetItem(serverConfigureWiget, i18n("Sieve Server"));
+    serverPageWidgetPage->setIcon(QIcon::fromTheme(QStringLiteral("network-workgroup")));
+    addPage(serverPageWidgetPage);
+
+    //Editor page
     QWidget *editorWidget = new QWidget;
     editorWidget->setObjectName(QStringLiteral("editorwidget"));
-    mTabWidget->addTab(editorWidget, i18n("Editor"));
 
-    layout = new QVBoxLayout;
-    editorWidget->setLayout(layout);
+    layout = new QVBoxLayout(editorWidget);
     mWrapText = new QCheckBox(i18n("Wrap Text"));
     mWrapText->setObjectName(QStringLiteral("wraptext"));
     layout->addWidget(mWrapText);
     layout->addStretch(100);
-    mainLayout->addWidget(mTabWidget);
-    mainLayout->addWidget(buttonBox);
+
+    KPageWidgetItem *editorPageWidgetPage = new KPageWidgetItem(editorWidget, i18n("Editor"));
+    editorPageWidgetPage->setIcon(QIcon::fromTheme(QStringLiteral("accessories-text-editor")));
+    addPage(editorPageWidgetPage);
+
+    //UserFeedBack config
+#ifdef WITH_KUSERFEEDBACK
+    QWidget *userFeedBackWidget = new QWidget;
+    userFeedBackWidget->setObjectName(QStringLiteral("userFeedBackWidget"));
+
+    mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
+
+    QHBoxLayout *userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
+    userFeedBackLayout->setContentsMargins(0, 0, 0, 0);
+    userFeedBackLayout->addWidget(mUserFeedbackWidget);
+
+    mUserFeedbackWidget->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
+    KPageWidgetItem *userFeedBackPageWidgetPage = new KPageWidgetItem(userFeedBackWidget, i18n("User Feedback"));
+    userFeedBackPageWidgetPage->setIcon(QIcon::fromTheme(QStringLiteral("preferences-other")));
+    addPage(userFeedBackPageWidgetPage);
+#endif
+
     loadServerSieveConfig();
     readConfig();
 }
@@ -93,6 +116,11 @@ void SieveEditorConfigureDialog::saveServerSieveConfig()
     PimCommon::ConfigureImmutableWidgetUtils::saveCheckBox(mCloseWallet, SieveEditorGlobalConfig::self()->closeWalletItem());
     PimCommon::ConfigureImmutableWidgetUtils::saveCheckBox(mWrapText, SieveEditorGlobalConfig::self()->wrapTextItem());
     SieveEditorGlobalConfig::self()->save();
+#ifdef WITH_KUSERFEEDBACK
+    // set current active mode + write back the config for future starts
+    UserFeedBackManager::self()->userFeedbackProvider()->setTelemetryMode(mUserFeedbackWidget->telemetryMode());
+    UserFeedBackManager::self()->userFeedbackProvider()->setSurveyInterval(mUserFeedbackWidget->surveyInterval());
+#endif
 }
 
 void SieveEditorConfigureDialog::readConfig()
